@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2011,2012,2013,2016,2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2011, 2012, 2013, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgencrypt.h"
 
@@ -101,12 +93,12 @@ KGpgEncrypt::nextLine(const QString &line)
 
 		if (line.startsWith(encStart)) {
 			m_currentFile = line.mid(encStart.length());
-			emit statusMessage(i18nc("Status message 'Encrypting <filename>' (operation starts)", "Encrypting %1", m_currentFile));
-			emit infoProgress(2 * m_fileIndex + 1, inputFiles.count() * 2);
+			Q_EMIT statusMessage(i18nc("Status message 'Encrypting <filename>' (operation starts)", "Encrypting %1", m_currentFile));
+			Q_EMIT infoProgress(2 * m_fileIndex + 1, inputFiles.count() * 2);
 		} else if (line == encDone) {
-			emit statusMessage(i18nc("Status message 'Encrypted <filename>' (operation was completed)", "Encrypted %1", m_currentFile));
+			Q_EMIT statusMessage(i18nc("Status message 'Encrypted <filename>' (operation was completed)", "Encrypted %1", m_currentFile));
 			m_fileIndex++;
-			emit infoProgress(2 * m_fileIndex, inputFiles.count() * 2);
+			Q_EMIT infoProgress(2 * m_fileIndex, inputFiles.count() * 2);
 		}
 	}
 
